@@ -25,13 +25,12 @@ class FrameSheet(Sheet):
     def __init__(
             self,
             worksheet: Worksheet,
-            start_col: int = 1,
-            start_row: int = 2,
     ):
         super().__init__(
             worksheet=worksheet,
-            start_col=start_col,
-            start_row=start_row,
+            end_of_sheet_rows_limit=20,
+            start_col=1,
+            start_row=2,
         )
 
         self.process_frame_elements()
@@ -53,7 +52,6 @@ class FrameSheet(Sheet):
 
             try:
                 self.process_cell(cell, col_index, row_index)
-                print(f"{row_index}\t\t{cell.value}")
             except EmptyValueError:
                 row_index += 1
                 continue
@@ -143,10 +141,9 @@ class FrameSheet(Sheet):
             row: int,
     ) -> None:
         element_parts_cells: List[Cell] = self.sheet_reader.read_cells(
-            start_col=self.start_col,
-            end_col=self.start_col,
             start_row=row + 1,
-            end_row=row + 4,
+            end_row=row + self.end_of_sheet_rows_limit,
+            start_col=self.start_col,
         )
 
         element_parts_matches: int = len([cell for cell in element_parts_cells
@@ -155,10 +152,9 @@ class FrameSheet(Sheet):
                                           is FrameCellValueTypes.ELEMENT_PART])
 
         frame_elements_cells: List[Cell] = self.sheet_reader.read_cells(
-            start_col=self.start_col,
-            end_col=self.start_col,
             start_row=row + 1,
-            end_row=row + 4,
+            end_row=row + self.end_of_sheet_rows_limit,
+            start_col=self.start_col,
         )
 
         frame_elements_matches: int = len([cell for cell in frame_elements_cells
